/***
 * Copyright (C) 1996-98. by Miroslav Zagorac <zaga@tirnanog.cc.fer.hr>
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <stdlib.h>

#include "../data/objects_def.h"
#include "../lib/lib_debug.h"

#include "cave.h"
#include "demo.h"
#include "graphics.h"
#include "help.h"
#include "keyboard.h"
#include "logo.h"
#include "level_editor.h"
#include "main.h"
#include "score.h"


#ifdef ANSI_FUNC

short logo_show (void)
#else

short logo_show ()
#endif
{
   unchar *logo_image;
   short   x, y, x_offset, y_offset, init_flag;
   time_t  demo_time;

   debug (("{%s()", __FUNCTION__))

   if ((logo_image = malloc (512L * 240)) == NULL)
      debug_return ("} == %d", FUNC_RET_ERROR)

   graph_scalebox (256, 120, logo, 512, 240, logo_image);

logo_loop:

   init_flag = 0;
   demo_time = time (NULL);
   x_offset  = y_offset  = 0;

   show_refresh_rate (1);

   while (1)
   {
      y_offset = (y_offset > 0) ? (y_offset - 1) : 15;

      graph_clearscreen (BLACK);

      graph_printf (10.5 * CHAR_16x16, 19.5 * CHAR_16x16, LIGHTGRAY, bd_font_16x16, "Original version by");
      graph_printf (6.5 * CHAR_16x16, 20.75 * CHAR_16x16, LIGHTGRAY, bd_font_16x16, "Peter Liepa with Chris Gray");
#ifdef USE_SVGALIB
      if (game_data.graphics_type == GRAPHICS_SVGALIB)
         graph_printf (CHAR_16x16, 22 * CHAR_16x16, GREEN, bd_font_16x16, "Linux SVGA version by Miroslav Zagorac");
#endif
#ifdef USE_X11
      if (game_data.graphics_type == GRAPHICS_X11)
         graph_printf (2 * CHAR_16x16, 22 * CHAR_16x16, CYAN, bd_font_16x16, "Unix X11 version by Miroslav Zagorac");
#endif
      graph_printf (10.5 * CHAR_16x16, 23.25 * CHAR_16x16, RED, bd_font_16x16, "Press fire to start");
      graph_printf (9 * CHAR_16x16, 28.5 * CHAR_16x16, BROWN, bd_font_16x16, "Press h for a key list");

      graph_printf (10.5 * CHAR_16x16, 24.5 * CHAR_16x16, RED, bd_font_16x16, "%d player,  Keyboard", game_data.players_number + 1);
      graph_printf (11 * CHAR_16x16, 25.75 * CHAR_16x16, RED, bd_font_16x16, "Cave %c,   Level %s", code_room (game_data.start_room), code_level (game_data.start_level));

      graph_fillbox (64, 40, 256 * 2, 120 * 2, BLUE);

      for (y = 40; y < 264; y += 8, x_offset ^= 8)
         for (x = 80; x < 560; x += 16)
            graph_fillbox (x + x_offset, y + y_offset, 4, 4, CYAN);

      graph_putboxmask (64, 40, 256 * 2, 120 * 2, logo_image);

      if (key_pressed_code (KEY_HELP, 1))
      {
         demo_time = time (NULL);

         show_game_help (1);
      }
      else
         show_game_help (-1);

      show_refresh_rate (0);
      graph_copyscreen ();

      if (! init_flag)
         graph_palette_fade (init_flag = 4);

      (void) key_update ();

      if (key_pressed_time (KEY_GAME_LEFT, 0, &demo_time))
#ifdef DEBUG
         game_data.start_room -= (game_data.start_room > 0) ? 1 : -(CAVE_MAXROOMEXT - 1);
      else if (key_pressed_time (KEY_GAME_RIGHT, 0, &demo_time))
         game_data.start_room += (game_data.start_room < (CAVE_MAXROOMEXT - 1)) ? 1 : -game_data.start_room;
#else
         game_data.start_room -= (game_data.start_room >= 4) ? 4 : -(CAVE_MAXROOM - 4);
      else if (key_pressed_time (KEY_GAME_RIGHT, 0, &demo_time))
         game_data.start_room += (game_data.start_room < (CAVE_MAXROOM - 4)) ? 4 : -game_data.start_room;
#endif
      else if (key_pressed_time (KEY_GAME_UP, 0, &demo_time))
         game_data.start_level += (game_data.start_level < (CAVE_MAXLEVEL - 1)) ? 1 : -game_data.start_level;
      else if (key_pressed_time (KEY_GAME_DOWN, 0, &demo_time))
         game_data.start_level -= game_data.start_level ? 1 : -(CAVE_MAXLEVEL - 1);
      else if (key_pressed_code (KEY_GAME_FIRE, 0))
         break;
      else if (key_pressed_time (KEY_GAME_PLAYERS, 0, &demo_time))
         game_data.players_number += (game_data.players_number < (MAX_PLAYERS - 1)) ? 1 : -game_data.players_number;
      else if (key_pressed_code (KEY_GAME_EDITOR, 0))
      {
         level_editor ();

         goto logo_loop;
      }
      else if (key_pressed_code (KEY_GAME_SCORE, 0))
      {
         score_top_ten ();

         goto logo_loop;
      }
#ifdef DEBUG
      else if (key_pressed_code (KEY_SNAPSHOT, 0))
         (void) graph_save_snapshot ();
#endif

      /***
       * Ako se ovdje nijedna tipka ne pritisne u roku od 20 sekundi, onda ce zapoceti demo.
       */
      if ((time (NULL) - demo_time) > 20)
      {
         game_demo ();

         goto logo_loop;
      }
   }

   graph_palette_fade (-4);
   graph_clearscreen (BLACK);
   free (logo_image);

   debug_return ("} == %d", FUNC_RET_OK)
}
